@@ -6,6 +6,8 @@ import time
 import sys
 import subprocess
 import base64
+import __main__
+import threading
 
 from Cheese.cheeseController import CheeseController
 from Cheese.variables import Variables
@@ -35,6 +37,9 @@ class AdminManager:
         elif (server.path.startswith("/admin/deleteLog")):
             AdminManager.__deleteLog(server)
             return
+        elif (server.path == "/admin/deleteAll"):
+            AdminManager.__deleteAll(server)
+            return
         elif (server.path == "/admin/getActiveLog"):
             AdminManager.__getActiveLog(server)
             return
@@ -107,7 +112,7 @@ class AdminManager:
             return
 
         log = args["log"]
-        path = f"{ResMan.logs()}/{log}"
+        path = ResMan.logs(log)
         if (not os.path.exists(path)):
             CheeseController.sendResponse(server, Error.FileNotFound)
             return
@@ -120,13 +125,24 @@ class AdminManager:
             Logger.fail("Error while removing log", e, silence=False)
             Error.sendCustomError(server, "File was not deleted", 500)
 
+    @staticmethod
+    def __deleteAll(server):
+        for root, dirs, files in os.walk(ResMan.logs()):
+            activeLog = sorted(files)[-1]
+
+        for root, dirs, files in os.walk(ResMan.logs()):
+            for file in files:
+                if (file == activeLog): continue
+                os.remove(ResMan.logs(file))
+        response = CheeseController.createResponse({"RESPONSE": "OK"})
+        CheeseController.sendResponse(server, response)
 
     @staticmethod
     def __getActiveLog(server):
         for root, dirs, files in os.walk(ResMan.logs()):
             activeLog = sorted(files)[-1]
         
-        log = ResMan.joinPath(ResMan.logs(), activeLog)
+        log = ResMan.logs(activeLog)
         with open(f"{log}", "r") as f:
             lines = f.readlines()
             min = 0
@@ -142,17 +158,18 @@ class AdminManager:
 
     @staticmethod
     def __restartServer(server):
-        Logger.adminInfo(20*"=", silence=False)
-        Logger.adminInfo("REQUEST FOR SERVER RESTART SUCCESSFULLY RECIEVED", silence=False)
-        Logger.adminInfo("Restart will start in 5 seconds", silence=False)
-        time.sleep(5)
-        for root, dirs, files in os.walk(ResMan.src()):
-            server.server.socket.close()
-            time.sleep(5)
-            if (os.name == "nt"):
-                subprocess.call(f"{sys.executable} \"{ResMan.joinPath(ResMan.src(), files[0])}\"")
-            else:
-                subprocess.call(f"{sys.executable} \"{ResMan.joinPath(ResMan.src(), files[0])}\"", shell=True)
+        restartThread = threading.Thread(target=AdminManager.__restart, args=(server,))
+        restartThread.start()
+        CheeseController.sendResponse(server, CheeseController.createResponse({}))
+
+    @staticmethod
+    def __restart(server):
+        time.sleep(0.5)
+        server.server.socket.close()
+        if (os.name == "nt"):
+            subprocess.call(f"{sys.executable} \"{__main__.__file__}\"")
+        else:
+            subprocess.call(f"{sys.executable} \"{__main__.__file__}\"", shell=True)
 
     @staticmethod
     def __shutDown(server):
