@@ -93,8 +93,12 @@ class CheeseController:
 
         `dict` is tested dictionary
         """
-        if (CheeseController.validateJson(keys, dict)): return
-        raise BadRequest("Wrong json structure")
+        missingKeys = ""
+        for key in keys:
+            if (key not in dict):
+                missingKeys += key + " "
+        if (missingKeys != ""):
+            raise BadRequest(f"Wrong json structure. Missing keys: {missingKeys}")
 
     @staticmethod
     def getPath(url) -> str:
