@@ -20,8 +20,10 @@ class FileHeaders:
         "mp3": "audio/mpeg",
         "gif": "image/gif",
         "png": "image/png",
+        "jpg": "image/jpg",
         "jpeg": "image/jpeg",
         "mp4": "video/mp4",
+        "mkv": "video/mp4",
         "mpeg": "video/mpeg"
     }
 
