@@ -3,7 +3,6 @@
 import os
 import json
 import base64
-import struct
 
 from Cheese.resourceManager import ResMan
 from Cheese.Logger import Logger
@@ -13,6 +12,10 @@ from Cheese.appSettings import Settings
 class Metadata:
 
     maxChar = 1114111
+
+    # this functionality has been added in v(1.4.63) 
+    # so if CHEESE_VERSION is missing in metadata the build version is less than 1.4.63
+    cheeseRelease = "unknown but less than 1.4.63" 
     
     repos = None
     contr = None
@@ -25,6 +28,9 @@ class Metadata:
         try:
             data = Metadata.read()
 
+            if ("CHEESE_VERSION" in data.keys()):
+                Metadata.cheeseRelease = data['CHEESE_VERSION']
+
             Metadata.repos = data["REPOSITORIES"]
             Metadata.contr = data["CONTROLLERS"]
             Metadata.tests = data["TESTS"]
@@ -75,6 +81,7 @@ class Metadata:
         Metadata.cleanInits()
         keys = data.keys()
         for key in keys:
+            if (key == "CHEESE_VERSION"): continue
             
             modules = data[key]
             for moduleKey in modules.keys():
@@ -87,11 +94,11 @@ class Metadata:
                 
                 splited = path.split("/")
                 for i, pth in enumerate(splited):
-                    with open(os.path.join(*splited[:i], pth, "__init__.py"), "a") as f:
+                    with open(os.path.join(*splited[:i], pth, "__init__.py"), "a", encoding="utf-8") as f:
                         if (len(splited) == 1 and splited[0] == ""): continue
                         f.write(f"from {'.'.join(splited)} import *\n")
 
-                with open(os.path.join(ResMan.root(), path, "__init__.py"), "a") as f:
+                with open(os.path.join(ResMan.root(), path, "__init__.py"), "a", encoding="utf-8") as f:
                     f.write(f"from {module['FILE'].replace('/', '.')} import {moduleKey}\n")
 
     @staticmethod
@@ -193,7 +200,7 @@ class Metadata:
         key = "Default"
         secPath = ResMan.root("secretPass")
         if (os.path.exists(secPath)):
-            with open(secPath, "r") as f:
+            with open(secPath, "r", encoding="utf-8") as f:
                 key = f.read().strip()
         return key
 
@@ -218,9 +225,9 @@ class Metadata:
                 code += Metadata.maxChar
             decoded += chr(code)
 
-            if (i == len(key)-1 or len(key) > len(data)):
-                if (decoded == key):
-                    decoded = ""
+            if (i == len(key) or len(key) > len(data)):
+                if (decoded[0:-1] == key and decoded[-1] == "{"):
+                    decoded = "{"
                 else:
                     raise PermissionError("Metadata has not been able to be decoded because decode key is invalid")
         if (key == "Default"):
