@@ -1,8 +1,8 @@
 #cheese
 
 import os
-import json
 
+from Cheese.variables import Variables
 from Cheese.resourceManager import ResMan
 from Cheese.Logger import Logger
 from Cheese.metadata import Metadata
@@ -27,6 +27,7 @@ class ProjectBuilder:
     def build(self):
         try:
             self.dictJson = {
+                "CHEESE_VERSION": Variables.release,
                 "CONTROLLERS": {}, 
                 "REPOSITORIES": {}, 
                 "TESTS": {},
@@ -69,7 +70,8 @@ class ProjectBuilder:
         queries = 0
         commits = 0
         for key in data.keys():
-            if (key == "SECRETS" or
+            if (key == "CHEESE_VERSION" or
+                key == "SECRETS" or
                 key == "ADMIN" or 
                 key == "SECURITY"): continue
                 
