@@ -5,8 +5,6 @@ import git
 import shutil
 import stat
 
-from Cheese.resourceManager import ResMan
-
 """
 Generates structure of Cheese Application
 """
@@ -15,10 +13,12 @@ class ProjectGenerator:
 
     @staticmethod
     def generate(path, generateFiles):
+        print("Cloning template repo...")
         repo = git.Repo.clone_from("https://github.com/KubaBoi/CheeseFramework.git", path)
 
         repo.git.checkout("template")  
 
+        print("Removing .git")
         for root, dirs, files in os.walk(os.path.join(path, ".git")):  
             for dir in dirs:
                 os.chmod(os.path.join(root, dir), stat.S_IRWXU)
@@ -30,13 +30,14 @@ class ProjectGenerator:
 
         if (not generateFiles):
             os.remove(os.path.join(src, "controllers", "HelloWorldController.py"))
-            os.remove(os.path.join(src, "models", "Hello.py"))
             os.remove(os.path.join(src, "repositories", "helloRepository.py"))
 
-        with open(os.path.join(path, "mainTemplate.py"), "r") as f:
+        print("Renaming files...")
+        with open(os.path.join(path, "mainTemplate.py"), "r", encoding="utf-8") as f:
             data = f.read()
 
-        with open(os.path.join(path, f"{os.path.basename(os.path.abspath(os.path.curdir))}.py"), "w") as f:
+        with open(os.path.join(path, f"{os.path.basename(os.path.abspath(os.path.curdir))}.py"), "w", encoding="utf-8") as f:
             f.write(data)
 
-        os.remove(os.path.join(path, "mainTemplate.py"))
\ No newline at end of file
+        os.remove(os.path.join(path, "mainTemplate.py"))
+        print("Done :)")
\ No newline at end of file
