@@ -58,18 +58,22 @@ class RepositoriesBuilder:
                 "QUERY": f"SELECT * FROM {repo['REPOSITORY']} WHERE :columnName=:value;",
                 "RETURN": "one"
             }
-            repo["METHODS"]["findByColumns"] = {
+            repo["METHODS"]["findWhere"] = {
                 "QUERY": f"SELECT * FROM {repo['REPOSITORY']} WHERE :filter;",
                 "RETURN": "array"
             }
-            repo["METHODS"]["findOneByColumns"] = {
+            repo["METHODS"]["findOneWhere"] = {
                 "QUERY": f"SELECT * FROM {repo['REPOSITORY']} WHERE :filter;",
                 "RETURN": "one"
             }
             repo["METHODS"]["findNewId"] = {
-                    "QUERY": f"SELECT MAX(id) FROM {repo['REPOSITORY']};",
-                    "RETURN": "num"
-                }
+                "QUERY": f"SELECT MAX(id) FROM {repo['REPOSITORY']};",
+                "RETURN": "num"
+            }
+            repo["METHODS"]["exists"] = {
+                "QUERY": f"SELECT CASE WHEN EXISTS (SELECT * from {repo['REPOSITORY']} WHERE :filter) THEN CAST(1 AS BIT) ELSE CAST(0 AS BIT) END;",
+                "RETURN": "bool"
+            }
 
     # prefabricated commit methods 
     @staticmethod
